extern crate argparse;

mod config;
mod board;
mod util;

use self::argparse::{ArgumentParser, Store};

fn main() {

    // Argument handling
    let mut config_location = config::default_config_file();
    let config_help = format!("Config file location, default {}", config_location);

    {
        let mut ap = ArgumentParser::new();
        ap.set_description("A Fallout terminal minigame inspired game.");

        ap.refer(&mut config_location)
            .add_option(
                &["--config"],
                Store,
                config_help.as_str()
            );
        ap.parse_args_or_exit();
    }

    // Config file handling
    if config_location == "" {
        panic!("No default config file found, and no config file path specified")
    }

    let conf = config::load_config_file(config_location);

    let screen = board::Screen::new(&conf);
    screen.intro();

    screen.w.clear();

    screen.initialize_game(conf);
}
